JsonFileConfigurationSource class

A ConfigurationSource for json files

Inheritance
Annotations

Constructors

JsonFileConfigurationSource(String filePath)

Properties

filePath → String
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

load() → Map<String, dynamic>
Return the configuration values of this source as a dictionary.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setManager(ConfigurationManager manager) → void
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited