Create class
Methods annotated with Create are factories for the return type.
eager if true, thg instance wil be created automatically. This is the default
scope tge scope. Default tis "singleton"
- Inheritance
-
- Object
- MethodAnnotation
- Create
Properties
Methods
-
apply(
TypeDescriptor type, MethodDescriptor method) → void -
callback executed by the type infrastructure
typetheTypeDescriptorof the annotated classmethodtheMethodDescriptorof the annotated methodoverride -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited